/****************************************************************************
**  CUBE        http://www.scalasca.org/                                   **
*****************************************************************************
**  Copyright (c) 2015-2020                                                **
**  Forschungszentrum Juelich GmbH, Juelich Supercomputing Centre          **
**                                                                         **
**  This software may be modified and distributed under the terms of       **
**  a BSD-style license.  See the COPYING file in the package base         **
**  directory for details.                                                 **
****************************************************************************/


#include "blade-config.h"
#include <iostream>

#include <QLabel>
#include <QGraphicsView>
#include <QGraphicsScene>
#include <QRectF>
#include <QVBoxLayout>
#include <QScrollArea>
#include <QAction>

#include "Service.h"
#include "LoadTraceWidget.h"

LoadTraceWidget::LoadTraceWidget(QString _path, cube::Cube* _cube, QWidget * parent):QWidget(parent),path(_path),cube(_cube)
{
    
    trace_loader_thread = new TraceLoaderThread(path, cube);
    trace = trace_loader_thread->getTrace();
    connect(trace_loader_thread, SIGNAL(traceLoaded()),
            this, SLOT(loadFinished()));  
    my_layout = new QVBoxLayout();
    this->setLayout( my_layout );
    
    
    trace_info_widget = new TraceInfoWidget( trace );
    my_layout->addWidget(trace_info_widget);
    
     connect(trace_info_widget, SIGNAL(loadTrace()),
             this, SLOT(load())); 

    
}
    
    
LoadTraceWidget::~LoadTraceWidget()
{

}
    
void
LoadTraceWidget::load()
{
    disconnect(trace_info_widget, SIGNAL(loadTrace()));   

    trace_loader_thread->set_load_filters( trace_info_widget->get_load_enter_filter(), trace_info_widget->get_load_leave_filter(), trace_info_widget->do_grouping()  );
    
    
    loading_message = new QLabel ();
    my_layout->addWidget(loading_message);
    loading_progress= new QProgressBar();
    my_layout->addWidget(loading_progress);
    

    loading_progress->setRange(0, 100);
    
    progress = 0;
    
    timer = new QTimer();
    connect(timer, SIGNAL(timeout()),
                this, SLOT(updateProgress()));   
    timer->start(10);
    trace_loader_thread->start();
}
   
   
  
   
void
LoadTraceWidget::loadFinished()
{
    trace = trace_loader_thread->getTrace();
    delete trace_loader_thread;
    timer->stop();
    emit traceLoaded();
}
   
void
LoadTraceWidget::updateProgress()
{
    loading_progress->setValue( trace_loader_thread->get_progress() * 100 );
    loading_message->setText( QString::fromStdString(trace_loader_thread->get_progress_message() ));
    
}
   
       
