/****************************************************************************
**  CUBE        http://www.scalasca.org/                                   **
*****************************************************************************
**  Copyright (c) 2015-2020                                                **
**  Forschungszentrum Juelich GmbH, Juelich Supercomputing Centre          **
**                                                                         **
**  This software may be modified and distributed under the terms of       **
**  a BSD-style license.  See the COPYING file in the package base         **
**  directory for details.                                                 **
****************************************************************************/


#include "blade-config.h"
#include <cmath>
#include <iostream>
#include <limits>
#include "ResolutionFilter.h"


ResolutionFilter::ResolutionFilter( )
{
    avail_pixels = std::numeric_limits<uint64_t>::max();
    avail_timestamps = avail_pixels;
    min_resolution= 1;
}


void
ResolutionFilter::set_available_pixels( uint64_t _p /* size of widget*/ )
{
    avail_pixels = _p;
    calculate_resolution();
}

void
ResolutionFilter::set_available_timestamps( uint64_t _w /* size of timestamp zoom*/)
{
    avail_timestamps = _w; 
    calculate_resolution();
}

void
ResolutionFilter::calculate_resolution( )
{
    min_resolution =  (uint64_t)floor((double)avail_timestamps / (double)avail_pixels);  
}
 
FilterResult 
ResolutionFilter::apply( TraceEvent * _te )
{
    if (!is_active())
        return FILTER_OK;
    
    FilterResult _result = FILTER_OK;
    uint64_t _time = (_te->get_end_timestamp() - _te->get_start_timestamp());
    if ( _time < min_resolution)
    {
        _result = FILTER_FAIL;
    }
 
    return _result;
}
    

bool 
ResolutionFilter::resolved( TraceEvent * _te1, TraceEvent * _te2 )
{
    return ( _te2->get_start_timestamp() - _te1->get_end_timestamp() > min_resolution);
}
