/****************************************************************************
**  CUBE        http://www.scalasca.org/                                   **
*****************************************************************************
**  Copyright (c) 2015-2020                                                **
**  Forschungszentrum Juelich GmbH, Juelich Supercomputing Centre          **
**                                                                         **
**  This software may be modified and distributed under the terms of       **
**  a BSD-style license.  See the COPYING file in the package base         **
**  directory for details.                                                 **
****************************************************************************/



#include "blade-config.h"
#include "TraceEventGroupN2NCompletionAnalyzer.h"
#include "Service.h"
#include "Trace.h"

extern Trace* trace;

TraceEventGroupN2NCompletionAnalyzer::TraceEventGroupN2NCompletionAnalyzer(): TraceEventGroupBarrierCompletionAnalyzer()
{

    name = "N2N Completion";
    description = "This pattern refers to\n"
                  "the time spent in MPI NxN\n"
                  "collective operation after \n"
                  "the first process has left\n" 
                  "the operation. ";
    min_max = (uint64_t)-1;
    
}

TraceEventGroupN2NCompletionAnalyzer::~TraceEventGroupN2NCompletionAnalyzer()
{
}


bool
TraceEventGroupN2NCompletionAnalyzer::probe(std::vector<TraceEvent*>& events)
{
    bool only_n2n = true;
    for (std::vector<TraceEvent*>::const_iterator iter = events.begin(); iter != events.end(); ++iter)
    {
        TraceEvent * _e = *iter;
        only_n2n &= (_e->get_region_role( ) == OTF2_REGION_ROLE_COLL_ALL2ALL );
    }
    if (!only_n2n)
        return false;
    
    min_max = (uint64_t)-1;
    for (std::vector<TraceEvent*>::iterator iter = events.begin(); iter != events.end(); ++iter)
    {
        min_max = std::min( min_max, (*iter)->get_end_timestamp() );
    } 
    return true;
}
