/****************************************************************************
**  CUBE        http://www.scalasca.org/                                   **
*****************************************************************************
**  Copyright (c) 2015-2020                                                **
**  Forschungszentrum Juelich GmbH, Juelich Supercomputing Centre          **
**                                                                         **
**  This software may be modified and distributed under the terms of       **
**  a BSD-style license.  See the COPYING file in the package base         **
**  directory for details.                                                 **
****************************************************************************/


#include "blade-config.h"
#include <iostream>
#include <cstdlib>
#include <algorithm> 
#include <QMouseEvent>
#include <QToolTip>
#include "TraceGroupGraphicsView.h"
#include "BladeUtils.h"
#include "TraceEventRect.h"
#include "Service.h"

TraceGroupGraphicsView::TraceGroupGraphicsView () : QGraphicsView( )
{
    setMouseTracking(true);
}; 
    
void
TraceGroupGraphicsView::mouseMoveEvent(QMouseEvent * _event)
{

    int _x = _event->x();
    int _y = _event->y();
    if ( _y < 0 || _y > height())
        return;
    
    if ( _x < 0 || _x > width())
    {
        return;
    }
    TraceEventRect * _rect = dynamic_cast<TraceEventRect*>( itemAt(_x, _y));
    if (_rect != NULL )
    {
        QString _tip = 
        "Region name: " +
            BladeUtils::shortCutRegionName(_rect->getRegionName())+"\n"
        "Start time : "+
        _rect->getStartTime() + "\n"
        "Duration : " +
        _rect->getDuration() + "\n"
        "Call Path: \n" +
        _rect->getCallPath() + "\n"
        "Metrics: \n" + 
            _rect->getMetrics();
            
        QToolTip::showText(mapToGlobal(QPoint(_x, _y)), _tip );     
    }else
    {
        QToolTip::hideText();
    }
    return;

}

