/****************************************************************************
**  CUBE        http://www.scalasca.org/                                   **
*****************************************************************************
**  Copyright (c) 2015-2020                                                **
**  Forschungszentrum Juelich GmbH, Juelich Supercomputing Centre          **
**                                                                         **
**  This software may be modified and distributed under the terms of       **
**  a BSD-style license.  See the COPYING file in the package base         **
**  directory for details.                                                 **
****************************************************************************/


#include "blade-config.h"
#include "TraceLoadLeaveFilter.h"



 
TraceLoadLeaveFilter::TraceLoadLeaveFilter()
{ 
    zoom_leave_filter = new ZoomLeaveFilter();
    resolution_filter = new ResolutionFilter();
}
    

 
TraceLoadLeaveFilter::~TraceLoadLeaveFilter()
{ 
    delete zoom_leave_filter;
    delete resolution_filter;
}
    

    
void
TraceLoadLeaveFilter::init(uint64_t s_time, uint64_t e_time, uint64_t _resolution)
{ 
    zoom_leave_filter->unzoom();
    zoom_leave_filter->set_zoom_window( s_time, e_time);
    
    resolution_filter->set_available_timestamps(e_time - s_time);
    
    if (_resolution != (uint64_t)(-1))
    {
	resolution_filter->set_available_pixels(_resolution /* size of widget*/ );
    } 
    zoom_leave_filter->print();
    resolution_filter->print();
}


FilterResult 
TraceLoadLeaveFilter::apply( TraceEvent * _te )
{ 
    if (!is_active())
        return FILTER_OK;
    
    FilterResult result = FILTER_OK;
    
     
    result = zoom_leave_filter->apply( _te);
    if (result == FILTER_FAIL)
	return FILTER_FAIL;
    
    resolution_filter->apply( _te);
    if (result == FILTER_FAIL)
	return FILTER_FAIL;

    return FILTER_OK;
}
    
