/****************************************************************************
**  CUBE        http://www.scalasca.org/                                   **
*****************************************************************************
**  Copyright (c) 2015-2020                                                **
**  Forschungszentrum Juelich GmbH, Juelich Supercomputing Centre          **
**                                                                         **
**  This software may be modified and distributed under the terms of       **
**  a BSD-style license.  See the COPYING file in the package base         **
**  directory for details.                                                 **
****************************************************************************/


#include "blade-config.h"
#include <algorithm>
#include "Service.h"
#include "GeneralEvaluation.h"
#include "TraceEventPoint.h"
#include "TraceEventSection.h"
#include "TraceEventStrippedSection.h"
#include "TraceEvent.h"



uint64_t location_extractor(uint64_t _l)
{
    return _l;
}




std::vector<TraceEventPoint>
bladeservices::transform_into_sorted_points(const std::vector<TraceEvent*> & _events)
{
    std::vector<TraceEventPoint> points;
    for ( std::vector<TraceEvent*>::const_iterator iter = _events.begin(); iter != _events.end(); ++iter)
    {
        std::pair<TraceEventPoint, TraceEventPoint> _p = (*iter)->get_trace_event_points();
        points.push_back( _p.first);
        points.push_back( _p.second);
    }
    
    sort( points.begin(), points.end(), TraceEventPoint::compareTraceEventPoints);
    
    return points;
    
}


std::vector<TraceEventSection>
bladeservices::transform_into_sections(const std::vector<TraceEventPoint> & _points, uint64_t z_start, uint64_t z_end)
{
    std::vector<TraceEventSection> sections;
    for ( std::vector<TraceEventPoint>::const_iterator iter = _points.begin(); iter != _points.end(); ++iter)
    {
        TraceEventSection section;
        for (; (
            !((*iter).is_including()) && 
            (*iter).is_start() &&
            !(!(*iter).is_start() && 
              (*(iter+1)).is_including()  
            )
        )   ; ++iter)
        {
        }

        section.set_start_point( *iter );
        ++iter;
        section.set_end_point( *iter );
        if (iter+1 != _points.end())
            --iter;
        if (section.intersects( z_start, z_end))
            sections.push_back(section);
    }

    
    return sections;
    
}



std::vector<TraceEventStrippedSection>
bladeservices::evaluate_sections(std::vector<TraceEventSection>&_sections, GeneralEvaluation * metric , uint64_t z_start, uint64_t z_end)
{
    std::vector<TraceEventStrippedSection> sections;
    for ( std::vector<TraceEventSection>::iterator iter = _sections.begin(); iter != _sections.end(); ++iter)
    {
        TraceEventStrippedSection section = metric->eval( *iter ); 
        sections.push_back(section);
    }

    if (sections.size()>0)
    {
        adjust_section( sections[0],z_start, z_end);
        adjust_section( sections[sections.size()-1],z_start, z_end);
    } 
    
    return sections;
    
}



void
bladeservices::adjust_section(TraceEventStrippedSection & _section, uint64_t z_start, uint64_t z_end)
{
    double _delta = _section.end_value - _section.start_value;

    
    if (_section.start_t < z_start)
    {
        uint64_t dt = z_start - _section.start_t;
        _section.start_value = _delta*dt/ (_section.end_t - _section.start_t) + _section.start_value;
        _section.start_t = z_start;
    }
    if (_section.end_t > z_end)
    {
        uint64_t dt = z_end - _section.start_t;
        _section.end_value  = (_delta)*dt/ (_section.end_t - _section.start_t ) +  _section.start_value;
        _section.end_t = z_end;
    }    
}


