/****************************************************************************
**  CUBE        http://www.scalasca.org/                                   **
*****************************************************************************
**  Copyright (c) 2015-2020                                                **
**  Forschungszentrum Juelich GmbH, Juelich Supercomputing Centre          **
**                                                                         **
**  This software may be modified and distributed under the terms of       **
**  a BSD-style license.  See the COPYING file in the package base         **
**  directory for details.                                                 **
****************************************************************************/


#include "blade-config.h"
#include <string>
#include <vector>
#include <inttypes.h>
#include <iostream>
#include <stack>
#include <utility>

#include "TraceEventSection.h"
#include "TraceEventStrippedSection.h"

TraceEventSection::TraceEventSection( )
{
}
      
void
TraceEventSection::set_start_point( const TraceEventPoint& _s)
{
    start = _s;
}

void
TraceEventSection::set_end_point( const TraceEventPoint& _e)
{
    end = _e;
}
   
bool
TraceEventSection::intersects(  uint64_t z_s,uint64_t z_e)
{
    return (start.get_timestamp() < z_e && end.get_timestamp() > z_s);
}

      
std::ostream&
operator<<( std::ostream& out, TraceEventSection & _p)
{
    out << "Section:(" << std::endl << 
    _p.start << _p.end
    << ")" << std::endl;

    return out;
}
 
TraceEventStrippedSection
TraceEventSection::get_stripped_section( size_t idx)
{
    TraceEventStrippedSection _sec;
    _sec.start_t = start.get_timestamp();
    _sec.end_t = end.get_timestamp();
    if (idx == ((size_t)(-1)-1)) // take timestamps as values...metric::time
    {
        _sec.start_value = _sec.start_t;
        _sec.end_value = _sec.end_t;
    }else
    {
        _sec.start_value = start.get_metric_value(idx);
        _sec.end_value = end.get_metric_value(idx);
    }
    return _sec;
}
  
  
TraceEventStrippedSection
TraceEventSection::get_stripped_section(double value)
{
    TraceEventStrippedSection _sec;
    _sec.start_t = start.get_timestamp();
    _sec.end_t = end.get_timestamp();
    _sec.start_value = value;
    _sec.end_value = value;
    return _sec;
}
   
  
  
