/****************************************************************************
**  CUBE        http://www.scalasca.org/                                   **
*****************************************************************************
**  Copyright (c) 2015-2016                                                **
**  Forschungszentrum Juelich GmbH, Juelich Supercomputing Centre          **
**                                                                         **
**  This software may be modified and distributed under the terms of       **
**  a BSD-style license.  See the COPYING file in the package base         **
**  directory for details.                                                 **
****************************************************************************/


#ifndef __FILTER_RULES_SET_H
#define __FILTER_RULES_SET_H 0

#include <vector>
#include "FilterRule.h"


namespace scorepion_plugin
{
    namespace filters
    {
        enum FilterType { INCLUDE_FILE=0, INCLUDE_REGION=1, EXCLUDE_FILE=2, EXCLUDE_REGION=3 };
        

        class FilterRulesSet
        {
        protected:
            FilterType rules_type;
            std::vector<FilterRule *> rules; 
            FilterResult match_result;
            
        public:
            FilterRulesSet( FilterType _rules_type = INCLUDE_FILE ) { rules_type = _rules_type;  };
            virtual
            ~FilterRulesSet();

             
            FilterType
            getFilterType() { return rules_type; }
            
            
            void
            AddRule( FilterRule * _rule );
             
            
            virtual
            void
            AddRule( const std::string & ) = 0;
             
            
            
            void 
            clearRules(); 
            
            bool
            isEmpty() const;    
            
            
            virtual
            FilterResult
            apply( cube::Vertex * ) const;
              
            
            virtual 
            void
            print(std::ostream&, bool intel=false ) const;
            
            std::ostream& 
            operator<< (std::ostream&);
            
             
            void
            write(std::ostream&) const;            

            void
            writeIntel(std::ostream&) const;            

        };
    }
 };

#endif
